@@ -10,7 +10,6 @@ sys.path.append(os.path.join(os.path.dirname(__file__), "../"))
 
 import logging
 
-from Crypto import Random
 from util.log import logfile_path
 from util.workers import get_worker_count, get_worker_connections_count
 
@@ -25,12 +24,6 @@ pythonpath = "."
 preload_app = True
 
 
-def post_fork(server, worker):
-    # Reset the Random library to ensure it won't raise the "PID check failed." error after
-    # gunicorn forks.
-    Random.atfork()
-
-
 def when_ready(server):
     logger = logging.getLogger(__name__)
     logger.debug("Starting web gunicorn with %s workers and %s worker class", workers, worker_class)
